@@ -170,6 +170,55 @@ def bake_plan_config(tmp_path, sample_bake_plan_config):
     return bake_config
 
 
+@pytest.fixture
+def sample_bake_plan_extended_config():
+    return """
+name: OE RPB tux CI test (LTS)
+description: A sanity test for OE RPB
+version: 1
+
+common: &commondata
+  container: ubuntu-20.04
+  envsetup: setup-environment
+  sources:
+    repo:
+      branch: qcom/dunfell
+      manifest: default.xml
+      url: https://github.com/96boards/oe-rpb-manifest.git
+  local_conf:
+    - INHERIT += 'buildstats buildstats-summary'
+    - INHERIT:remove = 'rm_work'
+  artifacts:
+    - $DEPLOY_DIR
+
+rpb: &rpb
+  distro: rpb
+  target: rpb-console-image
+
+rpb-wayland: &rpb-wayland
+  distro: rpb-wayland
+  target: rpb-console-image
+
+jobs:
+- name: rpb
+  bakes:
+    - { <<: [*commondata, *rpb], machine: dragonboard-410c, name: dragonboard-410c-rpb }
+    - { <<: [*commondata, *rpb], machine: dragonboard-845c, name: dragonboard-845c-rpb }
+- name: rpb-wayland
+  bakes:
+    - { <<: [*commondata, *rpb-wayland], machine: dragonboard-410c, name: dragonboard-410c-rpb-wayland }
+    - { <<: [*commondata, *rpb-wayland], machine: dragonboard-845c, name: dragonboard-845c-rpb-wayland }
+
+"""
+
+
+@pytest.fixture
+def bake_plan_extended_config(tmp_path, sample_bake_plan_extended_config):
+    bake_config = tmp_path / "sample_bake_plan.yml"
+    bake_config.write_text(sample_bake_plan_extended_config)
+    return bake_config
+
+
 @pytest.fixture
 def sample_plan_unknown_version():
     return """
