@@ -900,10 +900,13 @@ def results(build_attrs):
 
 class TestResults:
     def test_get_build(self, results, response, get, mocker):
+        url = results.tuxapi_url + "/v1/groups/{}/projects/{}/builds/{}".format(
+            results.group, results.project, results.uid
+        )
         response._content = b'{"a": "b"}'
 
         assert response.status_code == 200
-        assert results.get_build() == {"a": "b"}
+        assert results.get_build() == ({"a": "b"}, url)
         get.assert_called_with(
             results.tuxapi_url
             + "/v1/groups/{}/projects/{}/builds/{}".format(
@@ -915,10 +918,13 @@ class TestResults:
         )
 
     def test_get_oebuild(self, results, response, get, mocker):
+        url = results.tuxapi_url + "/v1/groups/{}/projects/{}/oebuilds/{}".format(
+            results.group, results.project, results.uid
+        )
         response._content = b'{"a": "b"}'
 
         assert response.status_code == 200
-        assert results.get_oebuild() == {"a": "b"}
+        assert results.get_oebuild() == ({"a": "b"}, url)
         get.assert_called_with(
             results.tuxapi_url
             + "/v1/groups/{}/projects/{}/oebuilds/{}".format(
