@@ -804,6 +804,23 @@ class TestPlanCli:
         tuxsuite.cli.main()
         plan.assert_called_once()
 
+    def test_bake_plan_cli(
+        self, mocker, monkeypatch, bake_plan_extended_config, tuxsuite_config, capsys
+    ):
+        plan = mocker.patch("tuxsuite.Plan")
+        monkeypatch.setattr(
+            sys,
+            "argv",
+            [
+                "tuxsuite",
+                "plan",
+                str(bake_plan_extended_config),
+            ],
+        )
+
+        tuxsuite.cli.main()
+        plan.assert_called_once()
+
 
 class TestTestCli:
     def test_test_no_args(self, monkeypatch, tuxsuite_config, capsys):
@@ -1168,6 +1185,10 @@ sample_plan_status = {
     },
 }
 
+# sample data in list fromat to be consumed by from json for result status
+
+sample_list_data = [sample_build_result, sample_oebuild_result]
+
 
 @pytest.fixture
 def build_result(tmp_path):
@@ -1201,6 +1222,16 @@ def plan_result(tmp_path):
     return plan_json
 
 
+@pytest.fixture
+def from_json_list(tmp_path):
+    # this fixture return path to a file containing oebuilds/test/builds data in list format,
+    # to be processed by result cli and return their status
+    list_data_path = tmp_path / "from_json_list.json"
+    with list_data_path.open("w") as f:
+        f.write(json.dumps(sample_list_data))
+    return list_data_path
+
+
 class TestResultsCli:
     def test_results_cli(
         self,
@@ -1212,6 +1243,7 @@ class TestResultsCli:
         test_result,
         plan_result,
         oebuild_result,
+        from_json_list,
     ):
         results = mocker.patch(
             "tuxsuite.Results.get_all", return_value=(sample_all_result, "http://api")
@@ -1372,6 +1404,23 @@ class TestResultsCli:
         tuxsuite.cli.main()
         results.assert_called_once()
 
+        # to test --from-json of result ( data type of list )
+        mocker.resetall()
+        results = mocker.patch(
+            "tuxsuite.Results.get_all", return_value=(sample_all_result, "http://api")
+        )
+        monkeypatch.setattr(
+            sys,
+            "argv",
+            [
+                "tuxsuite",
+                "results",
+                f"--from-json={from_json_list}",
+            ],
+        )
+        tuxsuite.cli.main()
+        results.assert_called_once()
+
     def test_results_cli_errors(self, mocker, monkeypatch, tmp_path, tuxsuite_config):
         results = mocker.patch(
             "tuxsuite.Results.get_all",
