@@ -160,6 +160,27 @@ def test_bake_plan_config(bake_plan_config):
     assert len(cfg.plan) == 3
 
 
+def test_bake_plan_extended_config(bake_plan_extended_config):
+    # bake plan files containing extra keys apart from allowed ones
+    # check for poky lts plan
+    cfg = PlanConfig("", "", bake_plan_extended_config)
+    assert cfg.name == "OE RPB tux CI test (LTS)"
+    assert cfg.description == "A sanity test for OE RPB"
+
+    cfg = PlanConfig("poky", "lts", bake_plan_extended_config)
+    assert cfg.name == "poky"
+    assert cfg.description == "lts"
+
+    assert len(cfg.plan) == 4
+
+    # checking if extra keys are picked up or not in jobs
+    assert cfg.plan[0]["build"]["distro"] == "rpb"
+    assert cfg.plan[0]["build"]["target"] == "rpb-console-image"
+
+    assert cfg.plan[2]["build"]["distro"] == "rpb-wayland"
+    assert cfg.plan[2]["build"]["target"] == "rpb-console-image"
+
+
 def test_plan_config_job_name(plan_config):
     cfg = PlanConfig("hello", "world", plan_config, "gcc-simple")
     assert len(cfg.plan) == 0
@@ -318,6 +339,55 @@ def test_bake_submit(config, bake_plan_config, mocker):
     assert len(plan.tests) == 0
 
 
+def test_bake_plan_extended_config_submit(config, bake_plan_extended_config, mocker):
+    cfg = PlanConfig("", "", bake_plan_extended_config)
+    plan = Plan(
+        cfg,
+        group="bake_tuxgrp",
+        project="bake_tuxprj",
+        local_manifest="https://gitlab.com/alok.ranjan1/test-project/-/blob/main/default.xml",
+    )
+
+    def post(url, headers, data):
+        assert "Authorization" in headers
+        if (
+            url
+            == "https://tuxapi.tuxsuite.com/v1/groups/bake_tuxgrp/projects/bake_tuxprj/plans"
+        ):
+            assert data == {
+                "name": "OE RPB tux CI test (LTS)",
+                "description": "A sanity test for OE RPB",
+            }
+            return {"uid": "my-plan-uid"}
+        if (
+            url
+            == "https://tuxapi.tuxsuite.com/v1/groups/bake_tuxgrp/projects/bake_tuxprj/oebuilds"
+        ):
+            assert isinstance(data, dict)
+            assert len(data["oebuilds"]) == 4
+            builds = data["oebuilds"]
+            index = 0
+            for p, d in zip(cfg.plan, builds):
+                assert p["build"]["container"] == d["container"]
+                assert p["build"]["distro"] == d["distro"]
+                assert p["build"]["envsetup"] == d["envsetup"]
+                assert p["build"]["machine"] == d["machine"]
+                assert p["build"]["sources"] == d["sources"]
+                assert p["build"]["target"] == d["target"]
+                assert d["plan"] == "my-plan-uid"
+                d["uid"] = f"my-build-{index:02}"
+                d["download_url"] = f"http://url/{d['uid']}"
+                index += 1
+            return builds
+
+        assert 0
+
+    mocker.patch("tuxsuite.build.post_request", post)
+    plan.submit()
+    assert len(plan.builds) == 4
+    assert len(plan.tests) == 0
+
+
 def test_get_plan(config, plan_config, mocker):
     cfg = PlanConfig("", "", plan_config)
     plan = Plan(
