@@ -51,7 +51,7 @@ def handle_submit(cmdargs, _, config):
     build_result = True
 
     if cmdargs.no_wait:
-        format_result(build.status)
+        format_result(build.status, tuxapi_url=build.build_data)
     else:
         build_result = wait_for_object(build)
 
