@@ -123,7 +123,7 @@ def format_result(result_json, tuxapi_url=None, prefix=""):
         else:
             icon = "🔧"
             cli_color = "bright_red"
-            message = result_json["status_message"]
+            message = result_json.get("status_message", "error")
         state = ResultState(
             state=state,
             status=result_json["state"],
